# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class KeyVault(pulumi.CustomResource):
    access_policies: pulumi.Output[list]
    """
    A list of up to 16 objects describing access policies, as described below.

      * `application_id` (`str`) - The object ID of an Application in Azure Active Directory.
      * `certificate_permissions` (`list`) - List of certificate permissions, must be one or more from the following: `backup`, `create`, `delete`, `deleteissuers`, `get`, `getissuers`, `import`, `list`, `listissuers`, `managecontacts`, `manageissuers`, `purge`, `recover`, `restore`, `setissuers` and `update`.
      * `key_permissions` (`list`) - List of key permissions, must be one or more from the following: `backup`, `create`, `decrypt`, `delete`, `encrypt`, `get`, `import`, `list`, `purge`, `recover`, `restore`, `sign`, `unwrapKey`, `update`, `verify` and `wrapKey`.
      * `object_id` (`str`) - The object ID of a user, service principal or security group in the Azure Active Directory tenant for the vault. The object ID must be unique for the list of access policies.
      * `secret_permissions` (`list`) - List of secret permissions, must be one or more from the following: `backup`, `delete`, `get`, `list`, `purge`, `recover`, `restore` and `set`.
      * `storage_permissions` (`list`) - List of storage permissions, must be one or more from the following: `backup`, `delete`, `deletesas`, `get`, `getsas`, `list`, `listsas`, `purge`, `recover`, `regeneratekey`, `restore`, `set`, `setsas` and `update`.
      * `tenant_id` (`str`) - The Azure Active Directory tenant ID that should be used for authenticating requests to the key vault. Must match the `tenant_id` used above.
    """
    enabled_for_deployment: pulumi.Output[bool]
    """
    Boolean flag to specify whether Azure Virtual Machines are permitted to retrieve certificates stored as secrets from the key vault. Defaults to `false`.
    """
    enabled_for_disk_encryption: pulumi.Output[bool]
    """
    Boolean flag to specify whether Azure Disk Encryption is permitted to retrieve secrets from the vault and unwrap keys. Defaults to `false`.
    """
    enabled_for_template_deployment: pulumi.Output[bool]
    """
    Boolean flag to specify whether Azure Resource Manager is permitted to retrieve secrets from the key vault. Defaults to `false`.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the Key Vault. Changing this forces a new resource to be created.
    """
    network_acls: pulumi.Output[dict]
    """
    A `network_acls` block as defined below.

      * `bypass` (`str`) - Specifies which traffic can bypass the network rules. Possible values are `AzureServices` and `None`.
      * `default_action` (`str`) - The Default Action to use when no rules match from `ip_rules` / `virtual_network_subnet_ids`. Possible values are `Allow` and `Deny`.
      * `ip_rules` (`list`) - One or more IP Addresses, or CIDR Blocks which should be able to access the Key Vault.
      * `virtual_network_subnet_ids` (`list`) - One or more Subnet ID's which should be able to access this Key Vault.
    """
    purge_protection_enabled: pulumi.Output[bool]
    """
    Is Purge Protection enabled for this Key Vault? Defaults to `false`.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to create the Key Vault. Changing this forces a new resource to be created.
    """
    sku_name: pulumi.Output[str]
    """
    The Name of the SKU used for this Key Vault. Possible values are `standard` and `premium`.
    """
    soft_delete_enabled: pulumi.Output[bool]
    """
    Should Soft Delete be enabled for this Key Vault? Defaults to `false`.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    tenant_id: pulumi.Output[str]
    """
    The Azure Active Directory tenant ID that should be used for authenticating requests to the key vault.
    """
    vault_uri: pulumi.Output[str]
    """
    The URI of the Key Vault, used for performing operations on keys and secrets.
    """
    def __init__(__self__, resource_name, opts=None, access_policies=None, enabled_for_deployment=None, enabled_for_disk_encryption=None, enabled_for_template_deployment=None, location=None, name=None, network_acls=None, purge_protection_enabled=None, resource_group_name=None, sku_name=None, soft_delete_enabled=None, tags=None, tenant_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Key Vault.

        ## Disclaimers

        > **Note:** It's possible to define Key Vault Access Policies both within the `keyvault.KeyVault` resource via the `access_policy` block and by using the `keyvault.AccessPolicy` resource. However it's not possible to use both methods to manage Access Policies within a KeyVault, since there'll be conflicts.

        > **Note:** This provi will automatically recover a soft-deleted Key Vault during Creation if one is found - you can opt out of this using the `features` configuration within the Provider configuration block.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        example_key_vault = azure.keyvault.KeyVault("exampleKeyVault",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            enabled_for_disk_encryption=True,
            tenant_id=current.tenant_id,
            soft_delete_enabled=True,
            purge_protection_enabled=False,
            sku_name="standard",
            access_policies=[{
                "tenant_id": current.tenant_id,
                "object_id": current.object_id,
                "key_permissions": ["get"],
                "secret_permissions": ["get"],
                "storage_permissions": ["get"],
            }],
            network_acls={
                "default_action": "Deny",
                "bypass": "AzureServices",
            },
            tags={
                "environment": "Testing",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] access_policies: A list of up to 16 objects describing access policies, as described below.
        :param pulumi.Input[bool] enabled_for_deployment: Boolean flag to specify whether Azure Virtual Machines are permitted to retrieve certificates stored as secrets from the key vault. Defaults to `false`.
        :param pulumi.Input[bool] enabled_for_disk_encryption: Boolean flag to specify whether Azure Disk Encryption is permitted to retrieve secrets from the vault and unwrap keys. Defaults to `false`.
        :param pulumi.Input[bool] enabled_for_template_deployment: Boolean flag to specify whether Azure Resource Manager is permitted to retrieve secrets from the key vault. Defaults to `false`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] network_acls: A `network_acls` block as defined below.
        :param pulumi.Input[bool] purge_protection_enabled: Is Purge Protection enabled for this Key Vault? Defaults to `false`.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Key Vault. Changing this forces a new resource to be created.
        :param pulumi.Input[str] sku_name: The Name of the SKU used for this Key Vault. Possible values are `standard` and `premium`.
        :param pulumi.Input[bool] soft_delete_enabled: Should Soft Delete be enabled for this Key Vault? Defaults to `false`.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory tenant ID that should be used for authenticating requests to the key vault.

        The **access_policies** object supports the following:

          * `application_id` (`pulumi.Input[str]`) - The object ID of an Application in Azure Active Directory.
          * `certificate_permissions` (`pulumi.Input[list]`) - List of certificate permissions, must be one or more from the following: `backup`, `create`, `delete`, `deleteissuers`, `get`, `getissuers`, `import`, `list`, `listissuers`, `managecontacts`, `manageissuers`, `purge`, `recover`, `restore`, `setissuers` and `update`.
          * `key_permissions` (`pulumi.Input[list]`) - List of key permissions, must be one or more from the following: `backup`, `create`, `decrypt`, `delete`, `encrypt`, `get`, `import`, `list`, `purge`, `recover`, `restore`, `sign`, `unwrapKey`, `update`, `verify` and `wrapKey`.
          * `object_id` (`pulumi.Input[str]`) - The object ID of a user, service principal or security group in the Azure Active Directory tenant for the vault. The object ID must be unique for the list of access policies.
          * `secret_permissions` (`pulumi.Input[list]`) - List of secret permissions, must be one or more from the following: `backup`, `delete`, `get`, `list`, `purge`, `recover`, `restore` and `set`.
          * `storage_permissions` (`pulumi.Input[list]`) - List of storage permissions, must be one or more from the following: `backup`, `delete`, `deletesas`, `get`, `getsas`, `list`, `listsas`, `purge`, `recover`, `regeneratekey`, `restore`, `set`, `setsas` and `update`.
          * `tenant_id` (`pulumi.Input[str]`) - The Azure Active Directory tenant ID that should be used for authenticating requests to the key vault. Must match the `tenant_id` used above.

        The **network_acls** object supports the following:

          * `bypass` (`pulumi.Input[str]`) - Specifies which traffic can bypass the network rules. Possible values are `AzureServices` and `None`.
          * `default_action` (`pulumi.Input[str]`) - The Default Action to use when no rules match from `ip_rules` / `virtual_network_subnet_ids`. Possible values are `Allow` and `Deny`.
          * `ip_rules` (`pulumi.Input[list]`) - One or more IP Addresses, or CIDR Blocks which should be able to access the Key Vault.
          * `virtual_network_subnet_ids` (`pulumi.Input[list]`) - One or more Subnet ID's which should be able to access this Key Vault.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['access_policies'] = access_policies
            __props__['enabled_for_deployment'] = enabled_for_deployment
            __props__['enabled_for_disk_encryption'] = enabled_for_disk_encryption
            __props__['enabled_for_template_deployment'] = enabled_for_template_deployment
            __props__['location'] = location
            __props__['name'] = name
            __props__['network_acls'] = network_acls
            __props__['purge_protection_enabled'] = purge_protection_enabled
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if sku_name is None:
                raise TypeError("Missing required property 'sku_name'")
            __props__['sku_name'] = sku_name
            __props__['soft_delete_enabled'] = soft_delete_enabled
            __props__['tags'] = tags
            if tenant_id is None:
                raise TypeError("Missing required property 'tenant_id'")
            __props__['tenant_id'] = tenant_id
            __props__['vault_uri'] = None
        super(KeyVault, __self__).__init__(
            'azure:keyvault/keyVault:KeyVault',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, access_policies=None, enabled_for_deployment=None, enabled_for_disk_encryption=None, enabled_for_template_deployment=None, location=None, name=None, network_acls=None, purge_protection_enabled=None, resource_group_name=None, sku_name=None, soft_delete_enabled=None, tags=None, tenant_id=None, vault_uri=None):
        """
        Get an existing KeyVault resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] access_policies: A list of up to 16 objects describing access policies, as described below.
        :param pulumi.Input[bool] enabled_for_deployment: Boolean flag to specify whether Azure Virtual Machines are permitted to retrieve certificates stored as secrets from the key vault. Defaults to `false`.
        :param pulumi.Input[bool] enabled_for_disk_encryption: Boolean flag to specify whether Azure Disk Encryption is permitted to retrieve secrets from the vault and unwrap keys. Defaults to `false`.
        :param pulumi.Input[bool] enabled_for_template_deployment: Boolean flag to specify whether Azure Resource Manager is permitted to retrieve secrets from the key vault. Defaults to `false`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] network_acls: A `network_acls` block as defined below.
        :param pulumi.Input[bool] purge_protection_enabled: Is Purge Protection enabled for this Key Vault? Defaults to `false`.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Key Vault. Changing this forces a new resource to be created.
        :param pulumi.Input[str] sku_name: The Name of the SKU used for this Key Vault. Possible values are `standard` and `premium`.
        :param pulumi.Input[bool] soft_delete_enabled: Should Soft Delete be enabled for this Key Vault? Defaults to `false`.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory tenant ID that should be used for authenticating requests to the key vault.
        :param pulumi.Input[str] vault_uri: The URI of the Key Vault, used for performing operations on keys and secrets.

        The **access_policies** object supports the following:

          * `application_id` (`pulumi.Input[str]`) - The object ID of an Application in Azure Active Directory.
          * `certificate_permissions` (`pulumi.Input[list]`) - List of certificate permissions, must be one or more from the following: `backup`, `create`, `delete`, `deleteissuers`, `get`, `getissuers`, `import`, `list`, `listissuers`, `managecontacts`, `manageissuers`, `purge`, `recover`, `restore`, `setissuers` and `update`.
          * `key_permissions` (`pulumi.Input[list]`) - List of key permissions, must be one or more from the following: `backup`, `create`, `decrypt`, `delete`, `encrypt`, `get`, `import`, `list`, `purge`, `recover`, `restore`, `sign`, `unwrapKey`, `update`, `verify` and `wrapKey`.
          * `object_id` (`pulumi.Input[str]`) - The object ID of a user, service principal or security group in the Azure Active Directory tenant for the vault. The object ID must be unique for the list of access policies.
          * `secret_permissions` (`pulumi.Input[list]`) - List of secret permissions, must be one or more from the following: `backup`, `delete`, `get`, `list`, `purge`, `recover`, `restore` and `set`.
          * `storage_permissions` (`pulumi.Input[list]`) - List of storage permissions, must be one or more from the following: `backup`, `delete`, `deletesas`, `get`, `getsas`, `list`, `listsas`, `purge`, `recover`, `regeneratekey`, `restore`, `set`, `setsas` and `update`.
          * `tenant_id` (`pulumi.Input[str]`) - The Azure Active Directory tenant ID that should be used for authenticating requests to the key vault. Must match the `tenant_id` used above.

        The **network_acls** object supports the following:

          * `bypass` (`pulumi.Input[str]`) - Specifies which traffic can bypass the network rules. Possible values are `AzureServices` and `None`.
          * `default_action` (`pulumi.Input[str]`) - The Default Action to use when no rules match from `ip_rules` / `virtual_network_subnet_ids`. Possible values are `Allow` and `Deny`.
          * `ip_rules` (`pulumi.Input[list]`) - One or more IP Addresses, or CIDR Blocks which should be able to access the Key Vault.
          * `virtual_network_subnet_ids` (`pulumi.Input[list]`) - One or more Subnet ID's which should be able to access this Key Vault.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["access_policies"] = access_policies
        __props__["enabled_for_deployment"] = enabled_for_deployment
        __props__["enabled_for_disk_encryption"] = enabled_for_disk_encryption
        __props__["enabled_for_template_deployment"] = enabled_for_template_deployment
        __props__["location"] = location
        __props__["name"] = name
        __props__["network_acls"] = network_acls
        __props__["purge_protection_enabled"] = purge_protection_enabled
        __props__["resource_group_name"] = resource_group_name
        __props__["sku_name"] = sku_name
        __props__["soft_delete_enabled"] = soft_delete_enabled
        __props__["tags"] = tags
        __props__["tenant_id"] = tenant_id
        __props__["vault_uri"] = vault_uri
        return KeyVault(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Endpoint(pulumi.CustomResource):
    content_types_to_compresses: pulumi.Output[list]
    """
    An array of strings that indicates a content types on which compression will be applied. The value for the elements should be MIME types.
    """
    delivery_rules: pulumi.Output[list]
    """
    Rules for the rules engine. An endpoint can contain up until 4 of those rules that consist of conditions and actions. A `delivery_rule` blocks as defined below.

      * `cacheExpirationAction` (`dict`) - A `cache_expiration_action` block as defined above.
        * `behavior` (`str`) - The behavior of the cache. Valid values are `BypassCache`, `Override` and `SetIfMissing`.
        * `duration` (`str`) - Duration of the cache. Only allowed when `behavior` is set to `Override` or `SetIfMissing`. Format: `[d.]hh:mm:ss`

      * `cacheKeyQueryStringAction` (`dict`) - A `cache_key_query_string_action` block as defined above.
        * `behavior` (`str`) - The behavior of the cache key for query strings. Valid values are `Exclude`, `ExcludeAll`, `Include` and `IncludeAll`.
        * `parameters` (`str`) - Comma separated list of parameter values.

      * `cookiesConditions` (`list`) - A `cookies_condition` block as defined above.
        * `matchValues` (`list`) - List of values for the cookie.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `selector` (`str`) - Name of the cookie.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `deviceCondition` (`dict`) - A `device_condition` block as defined below.
        * `matchValues` (`list`) - Valid values are `Desktop` and `Mobile`.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Equal`.

      * `httpVersionConditions` (`list`) - A `http_version_condition` block as defined below.
        * `matchValues` (`list`) - Valid values are `0.9`, `1.0`, `1.1` and `2.0`.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Equal`.

      * `modifyRequestHeaderActions` (`list`) - A `modify_request_header_action` block as defined below.
        * `action` (`str`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
        * `name` (`str`) - The header name.
        * `value` (`str`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

      * `modifyResponseHeaderActions` (`list`) - A `modify_response_header_action` block as defined below.
        * `action` (`str`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
        * `name` (`str`) - The header name.
        * `value` (`str`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

      * `name` (`str`) - The Name which should be used for this Delivery Rule.
      * `order` (`float`) - The order used for this rule, which must be larger than 1.
      * `postArgConditions` (`list`) - A `post_arg_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `selector` (`str`) - Name of the post arg.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `queryStringConditions` (`list`) - A `query_string_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `remoteAddressConditions` (`list`) - A `remote_address_condition` block as defined below.
        * `matchValues` (`list`) - List of string values. For `GeoMatch` `operator` this should be a list of country codes (e.g. `US` or `DE`). List of IP address if `operator` equals to `IPMatch`.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `GeoMatch` and `IPMatch`.

      * `requestBodyConditions` (`list`) - A `request_body_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `requestHeaderConditions` (`list`) - A `request_header_condition` block as defined below.
        * `matchValues` (`list`) - List of header values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `selector` (`str`) - Header name.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `requestMethodCondition` (`dict`) - A `request_method_condition` block as defined below.
        * `matchValues` (`list`) - Valid values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `POST` and `PUT`.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Equal`.

      * `requestSchemeCondition` (`dict`) - A `request_scheme_condition` block as defined below.
        * `matchValues` (`list`) - Valid values are `HTTP` and `HTTPS`.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Equal`.

      * `requestUriConditions` (`list`) - A `request_uri_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `urlFileExtensionConditions` (`list`) - A `url_file_extension_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `urlFileNameConditions` (`list`) - A `url_file_name_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `urlPathConditions` (`list`) - A `url_path_condition` block as defined below.
        * `matchValues` (`list`) - List of string values.
        * `negateCondition` (`bool`) - Defaults to `false`.
        * `operator` (`str`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
        * `transforms` (`list`) - Valid values are `Lowercase` and `Uppercase`.

      * `urlRedirectAction` (`dict`) - A `url_redirect_action` block as defined below.
        * `fragment` (`str`) - Specifies the fragment part of the URL. This value must not start with a `#`.
        * `hostname` (`str`) - Specifies the hostname part of the URL.
        * `path` (`str`) - Specifies the path part of the URL. This value must begin with a `/`.
        * `protocol` (`str`) - Specifies the protocol part of the URL. Valid values are `Http` and `Https`.
        * `queryString` (`str`) - Specifies the query string part of the URL. This value must not start with a `?` or `&` and must be in `<key>=<value>` format separated by `&`.
        * `redirectType` (`str`) - Type of the redirect. Valid values are `Found`, `Moved`, `PermanentRedirect` and `TemporaryRedirect`.

      * `urlRewriteAction` (`dict`) - A `url_rewrite_action` block as defined below.
        * `destination` (`str`) - This value must start with a `/` and can't be longer than 260 characters.
        * `preserveUnmatchedPath` (`bool`) - Defaults to `true`.
        * `sourcePattern` (`str`) - This value must start with a `/` and can't be longer than 260 characters.
    """
    geo_filters: pulumi.Output[list]
    """
    A set of Geo Filters for this CDN Endpoint. Each `geo_filter` block supports fields documented below.

      * `action` (`str`) - The Action of the Geo Filter. Possible values include `Allow` and `Block`.
      * `countryCodes` (`list`) - A List of two letter country codes (e.g. `US`, `GB`) to be associated with this Geo Filter.
      * `relative_path` (`str`) - The relative path applicable to geo filter.
    """
    global_delivery_rule: pulumi.Output[dict]
    """
    Actions that are valid for all resources regardless of any conditions. A `global_delivery_rule` block as defined below.

      * `cacheExpirationAction` (`dict`) - A `cache_expiration_action` block as defined above.
        * `behavior` (`str`) - The behavior of the cache. Valid values are `BypassCache`, `Override` and `SetIfMissing`.
        * `duration` (`str`) - Duration of the cache. Only allowed when `behavior` is set to `Override` or `SetIfMissing`. Format: `[d.]hh:mm:ss`

      * `cacheKeyQueryStringAction` (`dict`) - A `cache_key_query_string_action` block as defined above.
        * `behavior` (`str`) - The behavior of the cache key for query strings. Valid values are `Exclude`, `ExcludeAll`, `Include` and `IncludeAll`.
        * `parameters` (`str`) - Comma separated list of parameter values.

      * `modifyRequestHeaderActions` (`list`) - A `modify_request_header_action` block as defined below.
        * `action` (`str`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
        * `name` (`str`) - The header name.
        * `value` (`str`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

      * `modifyResponseHeaderActions` (`list`) - A `modify_response_header_action` block as defined below.
        * `action` (`str`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
        * `name` (`str`) - The header name.
        * `value` (`str`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

      * `urlRedirectAction` (`dict`) - A `url_redirect_action` block as defined below.
        * `fragment` (`str`) - Specifies the fragment part of the URL. This value must not start with a `#`.
        * `hostname` (`str`) - Specifies the hostname part of the URL.
        * `path` (`str`) - Specifies the path part of the URL. This value must begin with a `/`.
        * `protocol` (`str`) - Specifies the protocol part of the URL. Valid values are `Http` and `Https`.
        * `queryString` (`str`) - Specifies the query string part of the URL. This value must not start with a `?` or `&` and must be in `<key>=<value>` format separated by `&`.
        * `redirectType` (`str`) - Type of the redirect. Valid values are `Found`, `Moved`, `PermanentRedirect` and `TemporaryRedirect`.

      * `urlRewriteAction` (`dict`) - A `url_rewrite_action` block as defined below.
        * `destination` (`str`) - This value must start with a `/` and can't be longer than 260 characters.
        * `preserveUnmatchedPath` (`bool`) - Defaults to `true`.
        * `sourcePattern` (`str`) - This value must start with a `/` and can't be longer than 260 characters.
    """
    host_name: pulumi.Output[str]
    """
    A string that determines the hostname/IP address of the origin server. This string can be a domain name, Storage Account endpoint, Web App endpoint, IPv4 address or IPv6 address. Changing this forces a new resource to be created.
    """
    is_compression_enabled: pulumi.Output[bool]
    """
    Indicates whether compression is to be enabled. Defaults to false.
    """
    is_http_allowed: pulumi.Output[bool]
    """
    Defaults to `true`.
    """
    is_https_allowed: pulumi.Output[bool]
    """
    Defaults to `true`.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the origin. This is an arbitrary value. However, this value needs to be unique under the endpoint. Changing this forces a new resource to be created.
    """
    optimization_type: pulumi.Output[str]
    """
    What types of optimization should this CDN Endpoint optimize for? Possible values include `DynamicSiteAcceleration`, `GeneralMediaStreaming`, `GeneralWebDelivery`, `LargeFileDownload` and `VideoOnDemandMediaStreaming`.
    """
    origin_host_header: pulumi.Output[str]
    """
    The host header CDN provider will send along with content requests to origins. Defaults to the host name of the origin.
    """
    origin_path: pulumi.Output[str]
    """
    The path used at for origin requests.
    """
    origins: pulumi.Output[list]
    """
    The set of origins of the CDN endpoint. When multiple origins exist, the first origin will be used as primary and rest will be used as failover options. Each `origin` block supports fields documented below.

      * `host_name` (`str`) - A string that determines the hostname/IP address of the origin server. This string can be a domain name, Storage Account endpoint, Web App endpoint, IPv4 address or IPv6 address. Changing this forces a new resource to be created.
      * `httpPort` (`float`) - The HTTP port of the origin. Defaults to `80`. Changing this forces a new resource to be created.
      * `httpsPort` (`float`) - The HTTPS port of the origin. Defaults to `443`. Changing this forces a new resource to be created.
      * `name` (`str`) - The name of the origin. This is an arbitrary value. However, this value needs to be unique under the endpoint. Changing this forces a new resource to be created.
    """
    probe_path: pulumi.Output[str]
    """
    the path to a file hosted on the origin which helps accelerate delivery of the dynamic content and calculate the most optimal routes for the CDN. This is relative to the `origin_path`.
    """
    profile_name: pulumi.Output[str]
    """
    The CDN Profile to which to attach the CDN Endpoint.
    """
    querystring_caching_behaviour: pulumi.Output[str]
    """
    Sets query string caching behavior. Allowed values are `IgnoreQueryString`, `BypassCaching` and `UseQueryString`. Defaults to `IgnoreQueryString`.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to create the CDN Endpoint.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, content_types_to_compresses=None, delivery_rules=None, geo_filters=None, global_delivery_rule=None, is_compression_enabled=None, is_http_allowed=None, is_https_allowed=None, location=None, name=None, optimization_type=None, origin_host_header=None, origin_path=None, origins=None, probe_path=None, profile_name=None, querystring_caching_behaviour=None, resource_group_name=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        A CDN Endpoint is the entity within a CDN Profile containing configuration information regarding caching behaviours and origins. The CDN Endpoint is exposed using the URL format <endpointname>.azureedge.net.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_profile = azure.cdn.Profile("exampleProfile",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            sku="Standard_Verizon")
        example_endpoint = azure.cdn.Endpoint("exampleEndpoint",
            profile_name=example_profile.name,
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            origins=[{
                "name": "example",
                "host_name": "www.example.com",
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] content_types_to_compresses: An array of strings that indicates a content types on which compression will be applied. The value for the elements should be MIME types.
        :param pulumi.Input[list] delivery_rules: Rules for the rules engine. An endpoint can contain up until 4 of those rules that consist of conditions and actions. A `delivery_rule` blocks as defined below.
        :param pulumi.Input[list] geo_filters: A set of Geo Filters for this CDN Endpoint. Each `geo_filter` block supports fields documented below.
        :param pulumi.Input[dict] global_delivery_rule: Actions that are valid for all resources regardless of any conditions. A `global_delivery_rule` block as defined below.
        :param pulumi.Input[bool] is_compression_enabled: Indicates whether compression is to be enabled. Defaults to false.
        :param pulumi.Input[bool] is_http_allowed: Defaults to `true`.
        :param pulumi.Input[bool] is_https_allowed: Defaults to `true`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the origin. This is an arbitrary value. However, this value needs to be unique under the endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] optimization_type: What types of optimization should this CDN Endpoint optimize for? Possible values include `DynamicSiteAcceleration`, `GeneralMediaStreaming`, `GeneralWebDelivery`, `LargeFileDownload` and `VideoOnDemandMediaStreaming`.
        :param pulumi.Input[str] origin_host_header: The host header CDN provider will send along with content requests to origins. Defaults to the host name of the origin.
        :param pulumi.Input[str] origin_path: The path used at for origin requests.
        :param pulumi.Input[list] origins: The set of origins of the CDN endpoint. When multiple origins exist, the first origin will be used as primary and rest will be used as failover options. Each `origin` block supports fields documented below.
        :param pulumi.Input[str] probe_path: the path to a file hosted on the origin which helps accelerate delivery of the dynamic content and calculate the most optimal routes for the CDN. This is relative to the `origin_path`.
        :param pulumi.Input[str] profile_name: The CDN Profile to which to attach the CDN Endpoint.
        :param pulumi.Input[str] querystring_caching_behaviour: Sets query string caching behavior. Allowed values are `IgnoreQueryString`, `BypassCaching` and `UseQueryString`. Defaults to `IgnoreQueryString`.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the CDN Endpoint.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **delivery_rules** object supports the following:

          * `cacheExpirationAction` (`pulumi.Input[dict]`) - A `cache_expiration_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache. Valid values are `BypassCache`, `Override` and `SetIfMissing`.
            * `duration` (`pulumi.Input[str]`) - Duration of the cache. Only allowed when `behavior` is set to `Override` or `SetIfMissing`. Format: `[d.]hh:mm:ss`

          * `cacheKeyQueryStringAction` (`pulumi.Input[dict]`) - A `cache_key_query_string_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache key for query strings. Valid values are `Exclude`, `ExcludeAll`, `Include` and `IncludeAll`.
            * `parameters` (`pulumi.Input[str]`) - Comma separated list of parameter values.

          * `cookiesConditions` (`pulumi.Input[list]`) - A `cookies_condition` block as defined above.
            * `matchValues` (`pulumi.Input[list]`) - List of values for the cookie.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `selector` (`pulumi.Input[str]`) - Name of the cookie.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `deviceCondition` (`pulumi.Input[dict]`) - A `device_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `Desktop` and `Mobile`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `httpVersionConditions` (`pulumi.Input[list]`) - A `http_version_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `0.9`, `1.0`, `1.1` and `2.0`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `modifyRequestHeaderActions` (`pulumi.Input[list]`) - A `modify_request_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `modifyResponseHeaderActions` (`pulumi.Input[list]`) - A `modify_response_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `name` (`pulumi.Input[str]`) - The Name which should be used for this Delivery Rule.
          * `order` (`pulumi.Input[float]`) - The order used for this rule, which must be larger than 1.
          * `postArgConditions` (`pulumi.Input[list]`) - A `post_arg_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `selector` (`pulumi.Input[str]`) - Name of the post arg.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `queryStringConditions` (`pulumi.Input[list]`) - A `query_string_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `remoteAddressConditions` (`pulumi.Input[list]`) - A `remote_address_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values. For `GeoMatch` `operator` this should be a list of country codes (e.g. `US` or `DE`). List of IP address if `operator` equals to `IPMatch`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `GeoMatch` and `IPMatch`.

          * `requestBodyConditions` (`pulumi.Input[list]`) - A `request_body_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `requestHeaderConditions` (`pulumi.Input[list]`) - A `request_header_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of header values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `selector` (`pulumi.Input[str]`) - Header name.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `requestMethodCondition` (`pulumi.Input[dict]`) - A `request_method_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `POST` and `PUT`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `requestSchemeCondition` (`pulumi.Input[dict]`) - A `request_scheme_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `HTTP` and `HTTPS`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `requestUriConditions` (`pulumi.Input[list]`) - A `request_uri_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlFileExtensionConditions` (`pulumi.Input[list]`) - A `url_file_extension_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlFileNameConditions` (`pulumi.Input[list]`) - A `url_file_name_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlPathConditions` (`pulumi.Input[list]`) - A `url_path_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlRedirectAction` (`pulumi.Input[dict]`) - A `url_redirect_action` block as defined below.
            * `fragment` (`pulumi.Input[str]`) - Specifies the fragment part of the URL. This value must not start with a `#`.
            * `hostname` (`pulumi.Input[str]`) - Specifies the hostname part of the URL.
            * `path` (`pulumi.Input[str]`) - Specifies the path part of the URL. This value must begin with a `/`.
            * `protocol` (`pulumi.Input[str]`) - Specifies the protocol part of the URL. Valid values are `Http` and `Https`.
            * `queryString` (`pulumi.Input[str]`) - Specifies the query string part of the URL. This value must not start with a `?` or `&` and must be in `<key>=<value>` format separated by `&`.
            * `redirectType` (`pulumi.Input[str]`) - Type of the redirect. Valid values are `Found`, `Moved`, `PermanentRedirect` and `TemporaryRedirect`.

          * `urlRewriteAction` (`pulumi.Input[dict]`) - A `url_rewrite_action` block as defined below.
            * `destination` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.
            * `preserveUnmatchedPath` (`pulumi.Input[bool]`) - Defaults to `true`.
            * `sourcePattern` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.

        The **geo_filters** object supports the following:

          * `action` (`pulumi.Input[str]`) - The Action of the Geo Filter. Possible values include `Allow` and `Block`.
          * `countryCodes` (`pulumi.Input[list]`) - A List of two letter country codes (e.g. `US`, `GB`) to be associated with this Geo Filter.
          * `relative_path` (`pulumi.Input[str]`) - The relative path applicable to geo filter.

        The **global_delivery_rule** object supports the following:

          * `cacheExpirationAction` (`pulumi.Input[dict]`) - A `cache_expiration_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache. Valid values are `BypassCache`, `Override` and `SetIfMissing`.
            * `duration` (`pulumi.Input[str]`) - Duration of the cache. Only allowed when `behavior` is set to `Override` or `SetIfMissing`. Format: `[d.]hh:mm:ss`

          * `cacheKeyQueryStringAction` (`pulumi.Input[dict]`) - A `cache_key_query_string_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache key for query strings. Valid values are `Exclude`, `ExcludeAll`, `Include` and `IncludeAll`.
            * `parameters` (`pulumi.Input[str]`) - Comma separated list of parameter values.

          * `modifyRequestHeaderActions` (`pulumi.Input[list]`) - A `modify_request_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `modifyResponseHeaderActions` (`pulumi.Input[list]`) - A `modify_response_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `urlRedirectAction` (`pulumi.Input[dict]`) - A `url_redirect_action` block as defined below.
            * `fragment` (`pulumi.Input[str]`) - Specifies the fragment part of the URL. This value must not start with a `#`.
            * `hostname` (`pulumi.Input[str]`) - Specifies the hostname part of the URL.
            * `path` (`pulumi.Input[str]`) - Specifies the path part of the URL. This value must begin with a `/`.
            * `protocol` (`pulumi.Input[str]`) - Specifies the protocol part of the URL. Valid values are `Http` and `Https`.
            * `queryString` (`pulumi.Input[str]`) - Specifies the query string part of the URL. This value must not start with a `?` or `&` and must be in `<key>=<value>` format separated by `&`.
            * `redirectType` (`pulumi.Input[str]`) - Type of the redirect. Valid values are `Found`, `Moved`, `PermanentRedirect` and `TemporaryRedirect`.

          * `urlRewriteAction` (`pulumi.Input[dict]`) - A `url_rewrite_action` block as defined below.
            * `destination` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.
            * `preserveUnmatchedPath` (`pulumi.Input[bool]`) - Defaults to `true`.
            * `sourcePattern` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.

        The **origins** object supports the following:

          * `host_name` (`pulumi.Input[str]`) - A string that determines the hostname/IP address of the origin server. This string can be a domain name, Storage Account endpoint, Web App endpoint, IPv4 address or IPv6 address. Changing this forces a new resource to be created.
          * `httpPort` (`pulumi.Input[float]`) - The HTTP port of the origin. Defaults to `80`. Changing this forces a new resource to be created.
          * `httpsPort` (`pulumi.Input[float]`) - The HTTPS port of the origin. Defaults to `443`. Changing this forces a new resource to be created.
          * `name` (`pulumi.Input[str]`) - The name of the origin. This is an arbitrary value. However, this value needs to be unique under the endpoint. Changing this forces a new resource to be created.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['content_types_to_compresses'] = content_types_to_compresses
            __props__['delivery_rules'] = delivery_rules
            __props__['geo_filters'] = geo_filters
            __props__['global_delivery_rule'] = global_delivery_rule
            __props__['is_compression_enabled'] = is_compression_enabled
            __props__['is_http_allowed'] = is_http_allowed
            __props__['is_https_allowed'] = is_https_allowed
            __props__['location'] = location
            __props__['name'] = name
            __props__['optimization_type'] = optimization_type
            __props__['origin_host_header'] = origin_host_header
            __props__['origin_path'] = origin_path
            if origins is None:
                raise TypeError("Missing required property 'origins'")
            __props__['origins'] = origins
            __props__['probe_path'] = probe_path
            if profile_name is None:
                raise TypeError("Missing required property 'profile_name'")
            __props__['profile_name'] = profile_name
            __props__['querystring_caching_behaviour'] = querystring_caching_behaviour
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            __props__['host_name'] = None
        super(Endpoint, __self__).__init__(
            'azure:cdn/endpoint:Endpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, content_types_to_compresses=None, delivery_rules=None, geo_filters=None, global_delivery_rule=None, host_name=None, is_compression_enabled=None, is_http_allowed=None, is_https_allowed=None, location=None, name=None, optimization_type=None, origin_host_header=None, origin_path=None, origins=None, probe_path=None, profile_name=None, querystring_caching_behaviour=None, resource_group_name=None, tags=None):
        """
        Get an existing Endpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] content_types_to_compresses: An array of strings that indicates a content types on which compression will be applied. The value for the elements should be MIME types.
        :param pulumi.Input[list] delivery_rules: Rules for the rules engine. An endpoint can contain up until 4 of those rules that consist of conditions and actions. A `delivery_rule` blocks as defined below.
        :param pulumi.Input[list] geo_filters: A set of Geo Filters for this CDN Endpoint. Each `geo_filter` block supports fields documented below.
        :param pulumi.Input[dict] global_delivery_rule: Actions that are valid for all resources regardless of any conditions. A `global_delivery_rule` block as defined below.
        :param pulumi.Input[str] host_name: A string that determines the hostname/IP address of the origin server. This string can be a domain name, Storage Account endpoint, Web App endpoint, IPv4 address or IPv6 address. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] is_compression_enabled: Indicates whether compression is to be enabled. Defaults to false.
        :param pulumi.Input[bool] is_http_allowed: Defaults to `true`.
        :param pulumi.Input[bool] is_https_allowed: Defaults to `true`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the origin. This is an arbitrary value. However, this value needs to be unique under the endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] optimization_type: What types of optimization should this CDN Endpoint optimize for? Possible values include `DynamicSiteAcceleration`, `GeneralMediaStreaming`, `GeneralWebDelivery`, `LargeFileDownload` and `VideoOnDemandMediaStreaming`.
        :param pulumi.Input[str] origin_host_header: The host header CDN provider will send along with content requests to origins. Defaults to the host name of the origin.
        :param pulumi.Input[str] origin_path: The path used at for origin requests.
        :param pulumi.Input[list] origins: The set of origins of the CDN endpoint. When multiple origins exist, the first origin will be used as primary and rest will be used as failover options. Each `origin` block supports fields documented below.
        :param pulumi.Input[str] probe_path: the path to a file hosted on the origin which helps accelerate delivery of the dynamic content and calculate the most optimal routes for the CDN. This is relative to the `origin_path`.
        :param pulumi.Input[str] profile_name: The CDN Profile to which to attach the CDN Endpoint.
        :param pulumi.Input[str] querystring_caching_behaviour: Sets query string caching behavior. Allowed values are `IgnoreQueryString`, `BypassCaching` and `UseQueryString`. Defaults to `IgnoreQueryString`.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the CDN Endpoint.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.

        The **delivery_rules** object supports the following:

          * `cacheExpirationAction` (`pulumi.Input[dict]`) - A `cache_expiration_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache. Valid values are `BypassCache`, `Override` and `SetIfMissing`.
            * `duration` (`pulumi.Input[str]`) - Duration of the cache. Only allowed when `behavior` is set to `Override` or `SetIfMissing`. Format: `[d.]hh:mm:ss`

          * `cacheKeyQueryStringAction` (`pulumi.Input[dict]`) - A `cache_key_query_string_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache key for query strings. Valid values are `Exclude`, `ExcludeAll`, `Include` and `IncludeAll`.
            * `parameters` (`pulumi.Input[str]`) - Comma separated list of parameter values.

          * `cookiesConditions` (`pulumi.Input[list]`) - A `cookies_condition` block as defined above.
            * `matchValues` (`pulumi.Input[list]`) - List of values for the cookie.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `selector` (`pulumi.Input[str]`) - Name of the cookie.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `deviceCondition` (`pulumi.Input[dict]`) - A `device_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `Desktop` and `Mobile`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `httpVersionConditions` (`pulumi.Input[list]`) - A `http_version_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `0.9`, `1.0`, `1.1` and `2.0`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `modifyRequestHeaderActions` (`pulumi.Input[list]`) - A `modify_request_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `modifyResponseHeaderActions` (`pulumi.Input[list]`) - A `modify_response_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `name` (`pulumi.Input[str]`) - The Name which should be used for this Delivery Rule.
          * `order` (`pulumi.Input[float]`) - The order used for this rule, which must be larger than 1.
          * `postArgConditions` (`pulumi.Input[list]`) - A `post_arg_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `selector` (`pulumi.Input[str]`) - Name of the post arg.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `queryStringConditions` (`pulumi.Input[list]`) - A `query_string_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `remoteAddressConditions` (`pulumi.Input[list]`) - A `remote_address_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values. For `GeoMatch` `operator` this should be a list of country codes (e.g. `US` or `DE`). List of IP address if `operator` equals to `IPMatch`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `GeoMatch` and `IPMatch`.

          * `requestBodyConditions` (`pulumi.Input[list]`) - A `request_body_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `requestHeaderConditions` (`pulumi.Input[list]`) - A `request_header_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of header values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `selector` (`pulumi.Input[str]`) - Header name.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `requestMethodCondition` (`pulumi.Input[dict]`) - A `request_method_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `POST` and `PUT`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `requestSchemeCondition` (`pulumi.Input[dict]`) - A `request_scheme_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - Valid values are `HTTP` and `HTTPS`.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Equal`.

          * `requestUriConditions` (`pulumi.Input[list]`) - A `request_uri_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlFileExtensionConditions` (`pulumi.Input[list]`) - A `url_file_extension_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlFileNameConditions` (`pulumi.Input[list]`) - A `url_file_name_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlPathConditions` (`pulumi.Input[list]`) - A `url_path_condition` block as defined below.
            * `matchValues` (`pulumi.Input[list]`) - List of string values.
            * `negateCondition` (`pulumi.Input[bool]`) - Defaults to `false`.
            * `operator` (`pulumi.Input[str]`) - Valid values are `Any`, `BeginsWith`, `Contains`, `EndsWith`, `Equal`, `GreaterThan`, `GreaterThanOrEqual`, `LessThan` and `LessThanOrEqual`.
            * `transforms` (`pulumi.Input[list]`) - Valid values are `Lowercase` and `Uppercase`.

          * `urlRedirectAction` (`pulumi.Input[dict]`) - A `url_redirect_action` block as defined below.
            * `fragment` (`pulumi.Input[str]`) - Specifies the fragment part of the URL. This value must not start with a `#`.
            * `hostname` (`pulumi.Input[str]`) - Specifies the hostname part of the URL.
            * `path` (`pulumi.Input[str]`) - Specifies the path part of the URL. This value must begin with a `/`.
            * `protocol` (`pulumi.Input[str]`) - Specifies the protocol part of the URL. Valid values are `Http` and `Https`.
            * `queryString` (`pulumi.Input[str]`) - Specifies the query string part of the URL. This value must not start with a `?` or `&` and must be in `<key>=<value>` format separated by `&`.
            * `redirectType` (`pulumi.Input[str]`) - Type of the redirect. Valid values are `Found`, `Moved`, `PermanentRedirect` and `TemporaryRedirect`.

          * `urlRewriteAction` (`pulumi.Input[dict]`) - A `url_rewrite_action` block as defined below.
            * `destination` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.
            * `preserveUnmatchedPath` (`pulumi.Input[bool]`) - Defaults to `true`.
            * `sourcePattern` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.

        The **geo_filters** object supports the following:

          * `action` (`pulumi.Input[str]`) - The Action of the Geo Filter. Possible values include `Allow` and `Block`.
          * `countryCodes` (`pulumi.Input[list]`) - A List of two letter country codes (e.g. `US`, `GB`) to be associated with this Geo Filter.
          * `relative_path` (`pulumi.Input[str]`) - The relative path applicable to geo filter.

        The **global_delivery_rule** object supports the following:

          * `cacheExpirationAction` (`pulumi.Input[dict]`) - A `cache_expiration_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache. Valid values are `BypassCache`, `Override` and `SetIfMissing`.
            * `duration` (`pulumi.Input[str]`) - Duration of the cache. Only allowed when `behavior` is set to `Override` or `SetIfMissing`. Format: `[d.]hh:mm:ss`

          * `cacheKeyQueryStringAction` (`pulumi.Input[dict]`) - A `cache_key_query_string_action` block as defined above.
            * `behavior` (`pulumi.Input[str]`) - The behavior of the cache key for query strings. Valid values are `Exclude`, `ExcludeAll`, `Include` and `IncludeAll`.
            * `parameters` (`pulumi.Input[str]`) - Comma separated list of parameter values.

          * `modifyRequestHeaderActions` (`pulumi.Input[list]`) - A `modify_request_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `modifyResponseHeaderActions` (`pulumi.Input[list]`) - A `modify_response_header_action` block as defined below.
            * `action` (`pulumi.Input[str]`) - Action to be executed on a header value. Valid values are `Append`, `Delete` and `Overwrite`.
            * `name` (`pulumi.Input[str]`) - The header name.
            * `value` (`pulumi.Input[str]`) - The value of the header. Only needed when `action` is set to `Append` or `overwrite`.

          * `urlRedirectAction` (`pulumi.Input[dict]`) - A `url_redirect_action` block as defined below.
            * `fragment` (`pulumi.Input[str]`) - Specifies the fragment part of the URL. This value must not start with a `#`.
            * `hostname` (`pulumi.Input[str]`) - Specifies the hostname part of the URL.
            * `path` (`pulumi.Input[str]`) - Specifies the path part of the URL. This value must begin with a `/`.
            * `protocol` (`pulumi.Input[str]`) - Specifies the protocol part of the URL. Valid values are `Http` and `Https`.
            * `queryString` (`pulumi.Input[str]`) - Specifies the query string part of the URL. This value must not start with a `?` or `&` and must be in `<key>=<value>` format separated by `&`.
            * `redirectType` (`pulumi.Input[str]`) - Type of the redirect. Valid values are `Found`, `Moved`, `PermanentRedirect` and `TemporaryRedirect`.

          * `urlRewriteAction` (`pulumi.Input[dict]`) - A `url_rewrite_action` block as defined below.
            * `destination` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.
            * `preserveUnmatchedPath` (`pulumi.Input[bool]`) - Defaults to `true`.
            * `sourcePattern` (`pulumi.Input[str]`) - This value must start with a `/` and can't be longer than 260 characters.

        The **origins** object supports the following:

          * `host_name` (`pulumi.Input[str]`) - A string that determines the hostname/IP address of the origin server. This string can be a domain name, Storage Account endpoint, Web App endpoint, IPv4 address or IPv6 address. Changing this forces a new resource to be created.
          * `httpPort` (`pulumi.Input[float]`) - The HTTP port of the origin. Defaults to `80`. Changing this forces a new resource to be created.
          * `httpsPort` (`pulumi.Input[float]`) - The HTTPS port of the origin. Defaults to `443`. Changing this forces a new resource to be created.
          * `name` (`pulumi.Input[str]`) - The name of the origin. This is an arbitrary value. However, this value needs to be unique under the endpoint. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["content_types_to_compresses"] = content_types_to_compresses
        __props__["delivery_rules"] = delivery_rules
        __props__["geo_filters"] = geo_filters
        __props__["global_delivery_rule"] = global_delivery_rule
        __props__["host_name"] = host_name
        __props__["is_compression_enabled"] = is_compression_enabled
        __props__["is_http_allowed"] = is_http_allowed
        __props__["is_https_allowed"] = is_https_allowed
        __props__["location"] = location
        __props__["name"] = name
        __props__["optimization_type"] = optimization_type
        __props__["origin_host_header"] = origin_host_header
        __props__["origin_path"] = origin_path
        __props__["origins"] = origins
        __props__["probe_path"] = probe_path
        __props__["profile_name"] = profile_name
        __props__["querystring_caching_behaviour"] = querystring_caching_behaviour
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        return Endpoint(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetElasticPoolResult:
    """
    A collection of values returned by getElasticPool.
    """
    def __init__(__self__, id=None, license_type=None, location=None, max_size_bytes=None, max_size_gb=None, name=None, per_db_max_capacity=None, per_db_min_capacity=None, resource_group_name=None, server_name=None, tags=None, zone_redundant=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if license_type and not isinstance(license_type, str):
            raise TypeError("Expected argument 'license_type' to be a str")
        __self__.license_type = license_type
        """
        The license type to apply for this database.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        Specifies the supported Azure location where the resource exists.
        """
        if max_size_bytes and not isinstance(max_size_bytes, float):
            raise TypeError("Expected argument 'max_size_bytes' to be a float")
        __self__.max_size_bytes = max_size_bytes
        """
        The max data size of the elastic pool in bytes.
        """
        if max_size_gb and not isinstance(max_size_gb, float):
            raise TypeError("Expected argument 'max_size_gb' to be a float")
        __self__.max_size_gb = max_size_gb
        """
        The max data size of the elastic pool in gigabytes.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if per_db_max_capacity and not isinstance(per_db_max_capacity, float):
            raise TypeError("Expected argument 'per_db_max_capacity' to be a float")
        __self__.per_db_max_capacity = per_db_max_capacity
        """
        The maximum capacity any one database can consume.
        """
        if per_db_min_capacity and not isinstance(per_db_min_capacity, float):
            raise TypeError("Expected argument 'per_db_min_capacity' to be a float")
        __self__.per_db_min_capacity = per_db_min_capacity
        """
        The minimum capacity all databases are guaranteed.
        """
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        __self__.resource_group_name = resource_group_name
        if server_name and not isinstance(server_name, str):
            raise TypeError("Expected argument 'server_name' to be a str")
        __self__.server_name = server_name
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        A mapping of tags to assign to the resource.
        """
        if zone_redundant and not isinstance(zone_redundant, bool):
            raise TypeError("Expected argument 'zone_redundant' to be a bool")
        __self__.zone_redundant = zone_redundant
        """
        Whether or not this elastic pool is zone redundant.
        """
class AwaitableGetElasticPoolResult(GetElasticPoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetElasticPoolResult(
            id=self.id,
            license_type=self.license_type,
            location=self.location,
            max_size_bytes=self.max_size_bytes,
            max_size_gb=self.max_size_gb,
            name=self.name,
            per_db_max_capacity=self.per_db_max_capacity,
            per_db_min_capacity=self.per_db_min_capacity,
            resource_group_name=self.resource_group_name,
            server_name=self.server_name,
            tags=self.tags,
            zone_redundant=self.zone_redundant)

def get_elastic_pool(name=None,resource_group_name=None,server_name=None,opts=None):
    """
    Use this data source to access information about an existing SQL elastic pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.mssql.get_elastic_pool(name="mssqlelasticpoolname",
        resource_group_name="example-resources",
        server_name="example-sql-server")
    pulumi.export("elasticpoolId", example.id)
    ```


    :param str name: The name of the elastic pool.
    :param str resource_group_name: The name of the resource group which contains the elastic pool.
    :param str server_name: The name of the SQL Server which contains the elastic pool.
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['serverName'] = server_name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:mssql/getElasticPool:getElasticPool', __args__, opts=opts).value

    return AwaitableGetElasticPoolResult(
        id=__ret__.get('id'),
        license_type=__ret__.get('licenseType'),
        location=__ret__.get('location'),
        max_size_bytes=__ret__.get('maxSizeBytes'),
        max_size_gb=__ret__.get('maxSizeGb'),
        name=__ret__.get('name'),
        per_db_max_capacity=__ret__.get('perDbMaxCapacity'),
        per_db_min_capacity=__ret__.get('perDbMinCapacity'),
        resource_group_name=__ret__.get('resourceGroupName'),
        server_name=__ret__.get('serverName'),
        tags=__ret__.get('tags'),
        zone_redundant=__ret__.get('zoneRedundant'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Database(pulumi.CustomResource):
    auto_pause_delay_in_minutes: pulumi.Output[float]
    """
    Time in minutes after which database is automatically paused. A value of `-1` means that automatic pause is disabled. This property is only settable for General Purpose Serverless databases.
    """
    collation: pulumi.Output[str]
    """
    Specifies the collation of the database. Changing this forces a new resource to be created.
    """
    create_mode: pulumi.Output[str]
    """
    The create mode of the database. Possible values are `Copy`, `Default`, `OnlineSecondary`, `PointInTimeRestore`, `Restore`, `RestoreExternalBackup`, `RestoreExternalBackupSecondary`, `RestoreLongTermRetentionBackup` and `Secondary`.
    """
    creation_source_database_id: pulumi.Output[str]
    """
    The id of the source database to be referred to create the new database. This should only be used for databases with `create_mode` values that use another database as reference. Changing this forces a new resource to be created.
    """
    elastic_pool_id: pulumi.Output[str]
    """
    Specifies the ID of the elastic pool containing this database. Changing this forces a new resource to be created.
    """
    extended_auditing_policy: pulumi.Output[dict]
    """
    A `extended_auditing_policy` block as defined below.

      * `retention_in_days` (`float`) - Specifies the number of days to retain logs for in the storage account.
      * `storage_account_access_key` (`str`) - Specifies the access key to use for the auditing storage account.
      * `storageAccountAccessKeyIsSecondary` (`bool`) - Specifies whether `storage_account_access_key` value is the storage's secondary key.
      * `storage_endpoint` (`str`) - Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net).
    """
    license_type: pulumi.Output[str]
    """
    Specifies the license type applied to this database. Possible values are `LicenseIncluded` and `BasePrice`.
    """
    max_size_gb: pulumi.Output[float]
    """
    The max size of the database in gigabytes.
    """
    min_capacity: pulumi.Output[float]
    """
    Minimal capacity that database will always have allocated, if not paused. This property is only settable for General Purpose Serverless databases.
    """
    name: pulumi.Output[str]
    """
    The name of the Ms SQL Database. Changing this forces a new resource to be created.
    """
    read_replica_count: pulumi.Output[float]
    """
    The number of readonly secondary replicas associated with the database to which readonly application intent connections may be routed. This property is only settable for Hyperscale edition databases.
    """
    read_scale: pulumi.Output[bool]
    """
    If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
    """
    restore_point_in_time: pulumi.Output[str]
    """
    Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database. This property is only settable for `create_mode`= `PointInTimeRestore`  databases.
    """
    sample_name: pulumi.Output[str]
    """
    Specifies the name of the sample schema to apply when creating this database. Possible value is `AdventureWorksLT`.
    """
    server_id: pulumi.Output[str]
    """
    The id of the Ms SQL Server on which to create the database. Changing this forces a new resource to be created.
    """
    sku_name: pulumi.Output[str]
    """
    Specifies the name of the sku used by the database. Changing this forces a new resource to be created. For example, `GP_S_Gen5_2`,`HS_Gen4_1`,`BC_Gen5_2`, `ElasticPool`, `Basic`,`S0`, `P2` ,`DW100c`, `DS100`.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    threat_detection_policy: pulumi.Output[dict]
    """
    Threat detection policy configuration. The `threat_detection_policy` block supports fields documented below.

      * `disabled_alerts` (`list`) - Specifies a list of alerts which should be disabled. Possible values include `Access_Anomaly`, `Sql_Injection` and `Sql_Injection_Vulnerability`.
      * `email_account_admins` (`str`) - Should the account administrators be emailed when this alert is triggered?
      * `email_addresses` (`list`) - A list of email addresses which alerts should be sent to.
      * `retention_days` (`float`) - Specifies the number of days to keep in the Threat Detection audit logs.
      * `state` (`str`) - The State of the Policy. Possible values are `Enabled`, `Disabled` or `New`.
      * `storage_account_access_key` (`str`) - Specifies the identifier key of the Threat Detection audit storage account. Required if `state` is `Enabled`.
      * `storage_endpoint` (`str`) - Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs. Required if `state` is `Enabled`.
      * `useServerDefault` (`str`) - Should the default server policy be used? Defaults to `Disabled`.
    """
    zone_redundant: pulumi.Output[bool]
    """
    Whether or not this database is zone redundant, which means the replicas of this database will be spread across multiple availability zones. This property is only settable for Premium and Business Critical databases.
    """
    def __init__(__self__, resource_name, opts=None, auto_pause_delay_in_minutes=None, collation=None, create_mode=None, creation_source_database_id=None, elastic_pool_id=None, extended_auditing_policy=None, license_type=None, max_size_gb=None, min_capacity=None, name=None, read_replica_count=None, read_scale=None, restore_point_in_time=None, sample_name=None, server_id=None, sku_name=None, tags=None, threat_detection_policy=None, zone_redundant=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a MS SQL Database.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_account = azure.storage.Account("exampleAccount",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            account_tier="Standard",
            account_replication_type="LRS")
        example_sql_server = azure.sql.SqlServer("exampleSqlServer",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            version="12.0",
            administrator_login="4dm1n157r470r",
            administrator_login_password="4-v3ry-53cr37-p455w0rd")
        test = azure.mssql.Database("test",
            server_id=example_sql_server.id,
            collation="SQL_Latin1_General_CP1_CI_AS",
            license_type="LicenseIncluded",
            max_size_gb=4,
            read_scale=True,
            sku_name="BC_Gen5_2",
            zone_redundant=True,
            extended_auditing_policy={
                "storage_endpoint": example_account.primary_blob_endpoint,
                "storage_account_access_key": example_account.primary_access_key,
                "storageAccountAccessKeyIsSecondary": True,
                "retention_in_days": 6,
            },
            tags={
                "foo": "bar",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] auto_pause_delay_in_minutes: Time in minutes after which database is automatically paused. A value of `-1` means that automatic pause is disabled. This property is only settable for General Purpose Serverless databases.
        :param pulumi.Input[str] collation: Specifies the collation of the database. Changing this forces a new resource to be created.
        :param pulumi.Input[str] create_mode: The create mode of the database. Possible values are `Copy`, `Default`, `OnlineSecondary`, `PointInTimeRestore`, `Restore`, `RestoreExternalBackup`, `RestoreExternalBackupSecondary`, `RestoreLongTermRetentionBackup` and `Secondary`.
        :param pulumi.Input[str] creation_source_database_id: The id of the source database to be referred to create the new database. This should only be used for databases with `create_mode` values that use another database as reference. Changing this forces a new resource to be created.
        :param pulumi.Input[str] elastic_pool_id: Specifies the ID of the elastic pool containing this database. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] extended_auditing_policy: A `extended_auditing_policy` block as defined below.
        :param pulumi.Input[str] license_type: Specifies the license type applied to this database. Possible values are `LicenseIncluded` and `BasePrice`.
        :param pulumi.Input[float] max_size_gb: The max size of the database in gigabytes.
        :param pulumi.Input[float] min_capacity: Minimal capacity that database will always have allocated, if not paused. This property is only settable for General Purpose Serverless databases.
        :param pulumi.Input[str] name: The name of the Ms SQL Database. Changing this forces a new resource to be created.
        :param pulumi.Input[float] read_replica_count: The number of readonly secondary replicas associated with the database to which readonly application intent connections may be routed. This property is only settable for Hyperscale edition databases.
        :param pulumi.Input[bool] read_scale: If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
        :param pulumi.Input[str] restore_point_in_time: Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database. This property is only settable for `create_mode`= `PointInTimeRestore`  databases.
        :param pulumi.Input[str] sample_name: Specifies the name of the sample schema to apply when creating this database. Possible value is `AdventureWorksLT`.
        :param pulumi.Input[str] server_id: The id of the Ms SQL Server on which to create the database. Changing this forces a new resource to be created.
        :param pulumi.Input[str] sku_name: Specifies the name of the sku used by the database. Changing this forces a new resource to be created. For example, `GP_S_Gen5_2`,`HS_Gen4_1`,`BC_Gen5_2`, `ElasticPool`, `Basic`,`S0`, `P2` ,`DW100c`, `DS100`.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[dict] threat_detection_policy: Threat detection policy configuration. The `threat_detection_policy` block supports fields documented below.
        :param pulumi.Input[bool] zone_redundant: Whether or not this database is zone redundant, which means the replicas of this database will be spread across multiple availability zones. This property is only settable for Premium and Business Critical databases.

        The **extended_auditing_policy** object supports the following:

          * `retention_in_days` (`pulumi.Input[float]`) - Specifies the number of days to retain logs for in the storage account.
          * `storage_account_access_key` (`pulumi.Input[str]`) - Specifies the access key to use for the auditing storage account.
          * `storageAccountAccessKeyIsSecondary` (`pulumi.Input[bool]`) - Specifies whether `storage_account_access_key` value is the storage's secondary key.
          * `storage_endpoint` (`pulumi.Input[str]`) - Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net).

        The **threat_detection_policy** object supports the following:

          * `disabled_alerts` (`pulumi.Input[list]`) - Specifies a list of alerts which should be disabled. Possible values include `Access_Anomaly`, `Sql_Injection` and `Sql_Injection_Vulnerability`.
          * `email_account_admins` (`pulumi.Input[str]`) - Should the account administrators be emailed when this alert is triggered?
          * `email_addresses` (`pulumi.Input[list]`) - A list of email addresses which alerts should be sent to.
          * `retention_days` (`pulumi.Input[float]`) - Specifies the number of days to keep in the Threat Detection audit logs.
          * `state` (`pulumi.Input[str]`) - The State of the Policy. Possible values are `Enabled`, `Disabled` or `New`.
          * `storage_account_access_key` (`pulumi.Input[str]`) - Specifies the identifier key of the Threat Detection audit storage account. Required if `state` is `Enabled`.
          * `storage_endpoint` (`pulumi.Input[str]`) - Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs. Required if `state` is `Enabled`.
          * `useServerDefault` (`pulumi.Input[str]`) - Should the default server policy be used? Defaults to `Disabled`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auto_pause_delay_in_minutes'] = auto_pause_delay_in_minutes
            __props__['collation'] = collation
            __props__['create_mode'] = create_mode
            __props__['creation_source_database_id'] = creation_source_database_id
            __props__['elastic_pool_id'] = elastic_pool_id
            __props__['extended_auditing_policy'] = extended_auditing_policy
            __props__['license_type'] = license_type
            __props__['max_size_gb'] = max_size_gb
            __props__['min_capacity'] = min_capacity
            __props__['name'] = name
            __props__['read_replica_count'] = read_replica_count
            __props__['read_scale'] = read_scale
            __props__['restore_point_in_time'] = restore_point_in_time
            __props__['sample_name'] = sample_name
            if server_id is None:
                raise TypeError("Missing required property 'server_id'")
            __props__['server_id'] = server_id
            __props__['sku_name'] = sku_name
            __props__['tags'] = tags
            __props__['threat_detection_policy'] = threat_detection_policy
            __props__['zone_redundant'] = zone_redundant
        super(Database, __self__).__init__(
            'azure:mssql/database:Database',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auto_pause_delay_in_minutes=None, collation=None, create_mode=None, creation_source_database_id=None, elastic_pool_id=None, extended_auditing_policy=None, license_type=None, max_size_gb=None, min_capacity=None, name=None, read_replica_count=None, read_scale=None, restore_point_in_time=None, sample_name=None, server_id=None, sku_name=None, tags=None, threat_detection_policy=None, zone_redundant=None):
        """
        Get an existing Database resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] auto_pause_delay_in_minutes: Time in minutes after which database is automatically paused. A value of `-1` means that automatic pause is disabled. This property is only settable for General Purpose Serverless databases.
        :param pulumi.Input[str] collation: Specifies the collation of the database. Changing this forces a new resource to be created.
        :param pulumi.Input[str] create_mode: The create mode of the database. Possible values are `Copy`, `Default`, `OnlineSecondary`, `PointInTimeRestore`, `Restore`, `RestoreExternalBackup`, `RestoreExternalBackupSecondary`, `RestoreLongTermRetentionBackup` and `Secondary`.
        :param pulumi.Input[str] creation_source_database_id: The id of the source database to be referred to create the new database. This should only be used for databases with `create_mode` values that use another database as reference. Changing this forces a new resource to be created.
        :param pulumi.Input[str] elastic_pool_id: Specifies the ID of the elastic pool containing this database. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] extended_auditing_policy: A `extended_auditing_policy` block as defined below.
        :param pulumi.Input[str] license_type: Specifies the license type applied to this database. Possible values are `LicenseIncluded` and `BasePrice`.
        :param pulumi.Input[float] max_size_gb: The max size of the database in gigabytes.
        :param pulumi.Input[float] min_capacity: Minimal capacity that database will always have allocated, if not paused. This property is only settable for General Purpose Serverless databases.
        :param pulumi.Input[str] name: The name of the Ms SQL Database. Changing this forces a new resource to be created.
        :param pulumi.Input[float] read_replica_count: The number of readonly secondary replicas associated with the database to which readonly application intent connections may be routed. This property is only settable for Hyperscale edition databases.
        :param pulumi.Input[bool] read_scale: If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
        :param pulumi.Input[str] restore_point_in_time: Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database. This property is only settable for `create_mode`= `PointInTimeRestore`  databases.
        :param pulumi.Input[str] sample_name: Specifies the name of the sample schema to apply when creating this database. Possible value is `AdventureWorksLT`.
        :param pulumi.Input[str] server_id: The id of the Ms SQL Server on which to create the database. Changing this forces a new resource to be created.
        :param pulumi.Input[str] sku_name: Specifies the name of the sku used by the database. Changing this forces a new resource to be created. For example, `GP_S_Gen5_2`,`HS_Gen4_1`,`BC_Gen5_2`, `ElasticPool`, `Basic`,`S0`, `P2` ,`DW100c`, `DS100`.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[dict] threat_detection_policy: Threat detection policy configuration. The `threat_detection_policy` block supports fields documented below.
        :param pulumi.Input[bool] zone_redundant: Whether or not this database is zone redundant, which means the replicas of this database will be spread across multiple availability zones. This property is only settable for Premium and Business Critical databases.

        The **extended_auditing_policy** object supports the following:

          * `retention_in_days` (`pulumi.Input[float]`) - Specifies the number of days to retain logs for in the storage account.
          * `storage_account_access_key` (`pulumi.Input[str]`) - Specifies the access key to use for the auditing storage account.
          * `storageAccountAccessKeyIsSecondary` (`pulumi.Input[bool]`) - Specifies whether `storage_account_access_key` value is the storage's secondary key.
          * `storage_endpoint` (`pulumi.Input[str]`) - Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net).

        The **threat_detection_policy** object supports the following:

          * `disabled_alerts` (`pulumi.Input[list]`) - Specifies a list of alerts which should be disabled. Possible values include `Access_Anomaly`, `Sql_Injection` and `Sql_Injection_Vulnerability`.
          * `email_account_admins` (`pulumi.Input[str]`) - Should the account administrators be emailed when this alert is triggered?
          * `email_addresses` (`pulumi.Input[list]`) - A list of email addresses which alerts should be sent to.
          * `retention_days` (`pulumi.Input[float]`) - Specifies the number of days to keep in the Threat Detection audit logs.
          * `state` (`pulumi.Input[str]`) - The State of the Policy. Possible values are `Enabled`, `Disabled` or `New`.
          * `storage_account_access_key` (`pulumi.Input[str]`) - Specifies the identifier key of the Threat Detection audit storage account. Required if `state` is `Enabled`.
          * `storage_endpoint` (`pulumi.Input[str]`) - Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs. Required if `state` is `Enabled`.
          * `useServerDefault` (`pulumi.Input[str]`) - Should the default server policy be used? Defaults to `Disabled`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auto_pause_delay_in_minutes"] = auto_pause_delay_in_minutes
        __props__["collation"] = collation
        __props__["create_mode"] = create_mode
        __props__["creation_source_database_id"] = creation_source_database_id
        __props__["elastic_pool_id"] = elastic_pool_id
        __props__["extended_auditing_policy"] = extended_auditing_policy
        __props__["license_type"] = license_type
        __props__["max_size_gb"] = max_size_gb
        __props__["min_capacity"] = min_capacity
        __props__["name"] = name
        __props__["read_replica_count"] = read_replica_count
        __props__["read_scale"] = read_scale
        __props__["restore_point_in_time"] = restore_point_in_time
        __props__["sample_name"] = sample_name
        __props__["server_id"] = server_id
        __props__["sku_name"] = sku_name
        __props__["tags"] = tags
        __props__["threat_detection_policy"] = threat_detection_policy
        __props__["zone_redundant"] = zone_redundant
        return Database(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Key(pulumi.CustomResource):
    curve: pulumi.Output[str]
    """
    Specifies the curve to use when creating an `EC` key. Possible values are `P-256`, `P-384`, `P-521`, and `SECP256K1`. This field will be required in a future release if `key_type` is `EC` or `EC-HSM`. The API will default to `P-256` if nothing is specified. Changing this forces a new resource to be created.
    """
    e: pulumi.Output[str]
    """
    The RSA public exponent of this Key Vault Key.
    """
    expiration_date: pulumi.Output[str]
    """
    Expiration UTC datetime (Y-m-d'T'H:M:S'Z').
    """
    key_opts: pulumi.Output[list]
    """
    A list of JSON web key operations. Possible values include: `decrypt`, `encrypt`, `sign`, `unwrapKey`, `verify` and `wrapKey`. Please note these values are case sensitive.
    """
    key_size: pulumi.Output[float]
    """
    Specifies the Size of the RSA key to create in bytes. For example, 1024 or 2048. *Note*: This field is required if `key_type` is `RSA` or `RSA-HSM`. Changing this forces a new resource to be created.
    """
    key_type: pulumi.Output[str]
    """
    Specifies the Key Type to use for this Key Vault Key. Possible values are `EC` (Elliptic Curve), `EC-HSM`, `Oct` (Octet), `RSA` and `RSA-HSM`. Changing this forces a new resource to be created.
    """
    key_vault_id: pulumi.Output[str]
    """
    The ID of the Key Vault where the Key should be created. Changing this forces a new resource to be created.
    """
    n: pulumi.Output[str]
    """
    The RSA modulus of this Key Vault Key.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the Key Vault Key. Changing this forces a new resource to be created.
    """
    not_before_date: pulumi.Output[str]
    """
    Key not usable before the provided UTC datetime (Y-m-d'T'H:M:S'Z').
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    version: pulumi.Output[str]
    """
    The current version of the Key Vault Key.
    """
    x: pulumi.Output[str]
    """
    The EC X component of this Key Vault Key.
    """
    y: pulumi.Output[str]
    """
    The EC Y component of this Key Vault Key.
    """
    def __init__(__self__, resource_name, opts=None, curve=None, expiration_date=None, key_opts=None, key_size=None, key_type=None, key_vault_id=None, name=None, not_before_date=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Key Vault Key.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_random as random

        current = azure.core.get_client_config()
        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West US")
        server = random.RandomId("server",
            keepers={
                "ami_id": 1,
            },
            byte_length=8)
        example_key_vault = azure.keyvault.KeyVault("exampleKeyVault",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            tenant_id=current.tenant_id,
            sku_name="premium",
            access_policies=[{
                "tenant_id": current.tenant_id,
                "object_id": current.object_id,
                "key_permissions": [
                    "create",
                    "get",
                ],
                "secret_permissions": ["set"],
            }],
            tags={
                "environment": "Production",
            })
        generated = azure.keyvault.Key("generated",
            key_vault_id=example_key_vault.id,
            key_type="RSA",
            key_size=2048,
            key_opts=[
                "decrypt",
                "encrypt",
                "sign",
                "unwrapKey",
                "verify",
                "wrapKey",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] curve: Specifies the curve to use when creating an `EC` key. Possible values are `P-256`, `P-384`, `P-521`, and `SECP256K1`. This field will be required in a future release if `key_type` is `EC` or `EC-HSM`. The API will default to `P-256` if nothing is specified. Changing this forces a new resource to be created.
        :param pulumi.Input[str] expiration_date: Expiration UTC datetime (Y-m-d'T'H:M:S'Z').
        :param pulumi.Input[list] key_opts: A list of JSON web key operations. Possible values include: `decrypt`, `encrypt`, `sign`, `unwrapKey`, `verify` and `wrapKey`. Please note these values are case sensitive.
        :param pulumi.Input[float] key_size: Specifies the Size of the RSA key to create in bytes. For example, 1024 or 2048. *Note*: This field is required if `key_type` is `RSA` or `RSA-HSM`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] key_type: Specifies the Key Type to use for this Key Vault Key. Possible values are `EC` (Elliptic Curve), `EC-HSM`, `Oct` (Octet), `RSA` and `RSA-HSM`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] key_vault_id: The ID of the Key Vault where the Key should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault Key. Changing this forces a new resource to be created.
        :param pulumi.Input[str] not_before_date: Key not usable before the provided UTC datetime (Y-m-d'T'H:M:S'Z').
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['curve'] = curve
            __props__['expiration_date'] = expiration_date
            if key_opts is None:
                raise TypeError("Missing required property 'key_opts'")
            __props__['key_opts'] = key_opts
            __props__['key_size'] = key_size
            if key_type is None:
                raise TypeError("Missing required property 'key_type'")
            __props__['key_type'] = key_type
            if key_vault_id is None:
                raise TypeError("Missing required property 'key_vault_id'")
            __props__['key_vault_id'] = key_vault_id
            __props__['name'] = name
            __props__['not_before_date'] = not_before_date
            __props__['tags'] = tags
            __props__['e'] = None
            __props__['n'] = None
            __props__['version'] = None
            __props__['x'] = None
            __props__['y'] = None
        super(Key, __self__).__init__(
            'azure:keyvault/key:Key',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, curve=None, e=None, expiration_date=None, key_opts=None, key_size=None, key_type=None, key_vault_id=None, n=None, name=None, not_before_date=None, tags=None, version=None, x=None, y=None):
        """
        Get an existing Key resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] curve: Specifies the curve to use when creating an `EC` key. Possible values are `P-256`, `P-384`, `P-521`, and `SECP256K1`. This field will be required in a future release if `key_type` is `EC` or `EC-HSM`. The API will default to `P-256` if nothing is specified. Changing this forces a new resource to be created.
        :param pulumi.Input[str] e: The RSA public exponent of this Key Vault Key.
        :param pulumi.Input[str] expiration_date: Expiration UTC datetime (Y-m-d'T'H:M:S'Z').
        :param pulumi.Input[list] key_opts: A list of JSON web key operations. Possible values include: `decrypt`, `encrypt`, `sign`, `unwrapKey`, `verify` and `wrapKey`. Please note these values are case sensitive.
        :param pulumi.Input[float] key_size: Specifies the Size of the RSA key to create in bytes. For example, 1024 or 2048. *Note*: This field is required if `key_type` is `RSA` or `RSA-HSM`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] key_type: Specifies the Key Type to use for this Key Vault Key. Possible values are `EC` (Elliptic Curve), `EC-HSM`, `Oct` (Octet), `RSA` and `RSA-HSM`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] key_vault_id: The ID of the Key Vault where the Key should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] n: The RSA modulus of this Key Vault Key.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault Key. Changing this forces a new resource to be created.
        :param pulumi.Input[str] not_before_date: Key not usable before the provided UTC datetime (Y-m-d'T'H:M:S'Z').
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] version: The current version of the Key Vault Key.
        :param pulumi.Input[str] x: The EC X component of this Key Vault Key.
        :param pulumi.Input[str] y: The EC Y component of this Key Vault Key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["curve"] = curve
        __props__["e"] = e
        __props__["expiration_date"] = expiration_date
        __props__["key_opts"] = key_opts
        __props__["key_size"] = key_size
        __props__["key_type"] = key_type
        __props__["key_vault_id"] = key_vault_id
        __props__["n"] = n
        __props__["name"] = name
        __props__["not_before_date"] = not_before_date
        __props__["tags"] = tags
        __props__["version"] = version
        __props__["x"] = x
        __props__["y"] = y
        return Key(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetAlertRuleResult:
    """
    A collection of values returned by getAlertRule.
    """
    def __init__(__self__, id=None, log_analytics_workspace_id=None, name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if log_analytics_workspace_id and not isinstance(log_analytics_workspace_id, str):
            raise TypeError("Expected argument 'log_analytics_workspace_id' to be a str")
        __self__.log_analytics_workspace_id = log_analytics_workspace_id
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
class AwaitableGetAlertRuleResult(GetAlertRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertRuleResult(
            id=self.id,
            log_analytics_workspace_id=self.log_analytics_workspace_id,
            name=self.name)

def get_alert_rule(log_analytics_workspace_id=None,name=None,opts=None):
    """
    Use this data source to access information about an existing Sentinel Alert Rule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_analytics_workspace = azure.operationalinsights.get_analytics_workspace(name="example",
        resource_group_name="example-resources")
    example_alert_rule = azure.sentinel.get_alert_rule(name="existing",
        log_analytics_workspace_id=example_analytics_workspace.id)
    pulumi.export("id", example_alert_rule.id)
    ```


    :param str log_analytics_workspace_id: The ID of the Log Analytics Workspace this Sentinel Alert Rule belongs to.
    :param str name: The name which should be used for this Sentinel Alert Rule.
    """
    __args__ = dict()


    __args__['logAnalyticsWorkspaceId'] = log_analytics_workspace_id
    __args__['name'] = name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:sentinel/getAlertRule:getAlertRule', __args__, opts=opts).value

    return AwaitableGetAlertRuleResult(
        id=__ret__.get('id'),
        log_analytics_workspace_id=__ret__.get('logAnalyticsWorkspaceId'),
        name=__ret__.get('name'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('azure')

auxiliary_tenant_ids = __config__.get('auxiliaryTenantIds')

client_certificate_password = __config__.get('clientCertificatePassword')
"""
The password associated with the Client Certificate. For use when authenticating as a Service Principal using a Client
Certificate
"""

client_certificate_path = __config__.get('clientCertificatePath')
"""
The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service
Principal using a Client Certificate.
"""

client_id = __config__.get('clientId')
"""
The Client ID which should be used.
"""

client_secret = __config__.get('clientSecret')
"""
The Client Secret which should be used. For use When authenticating as a Service Principal using a Client Secret.
"""

disable_correlation_request_id = __config__.get('disableCorrelationRequestId')
"""
This will disable the x-ms-correlation-request-id header.
"""

disable_terraform_partner_id = __config__.get('disableTerraformPartnerId')
"""
This will disable the Terraform Partner ID which is used if a custom `partner_id` isn't specified.
"""

environment = __config__.get('environment') or (utilities.get_env('AZURE_ENVIRONMENT', 'ARM_ENVIRONMENT') or 'public')
"""
The Cloud Environment which should be used. Possible values are public, usgovernment, german, and china. Defaults to
public.
"""

features = __config__.get('features')

location = __config__.get('location') or utilities.get_env('ARM_LOCATION')

msi_endpoint = __config__.get('msiEndpoint')
"""
The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected
automatically.
"""

partner_id = __config__.get('partnerId')
"""
A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution.
"""

skip_credentials_validation = __config__.get('skipCredentialsValidation')
"""
This will cause the AzureRM Provider to skip verifying the credentials being used are valid.
"""

skip_provider_registration = __config__.get('skipProviderRegistration') or (utilities.get_env_bool('ARM_SKIP_PROVIDER_REGISTRATION') or False)
"""
Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already
registered?
"""

storage_use_azuread = __config__.get('storageUseAzuread') or (utilities.get_env_bool('ARM_STORAGE_USE_AZUREAD') or False)
"""
Should the AzureRM Provider use AzureAD to access the Storage Data Plane API's?
"""

subscription_id = __config__.get('subscriptionId') or (utilities.get_env('ARM_SUBSCRIPTION_ID') or '')
"""
The Subscription ID which should be used.
"""

tenant_id = __config__.get('tenantId')
"""
The Tenant ID which should be used.
"""

use_msi = __config__.get('useMsi')
"""
Allowed Managed Service Identity be used for Authentication.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class Environment(pulumi.CustomResource):
    allowed_user_ip_cidrs: pulumi.Output[list]
    """
    Allowed user added IP ranges on the ASE database. Use the addresses you want to set as the explicit egress address ranges.
    """
    front_end_scale_factor: pulumi.Output[float]
    """
    Scale factor for front end instances. Possible values are between `5` and `15`. Defaults to `15`.
    """
    internal_load_balancing_mode: pulumi.Output[str]
    """
    Specifies which endpoints to serve internally in the Virtual Network for the App Service Environment. Possible values are `None`, `Web`, `Publishing` and combined value `"Web, Publishing"`. Defaults to `None`.
    """
    location: pulumi.Output[str]
    """
    The location where the App Service Environment exists.
    """
    name: pulumi.Output[str]
    """
    The name of the App Service Environment. Changing this forces a new resource to be created.
    """
    pricing_tier: pulumi.Output[str]
    """
    Pricing tier for the front end instances. Possible values are `I1`, `I2` and `I3`. Defaults to `I1`.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the Resource Group where the App Service Environment exists. Defaults to the Resource Group of the Subnet (specified by `subnet_id`).
    """
    subnet_id: pulumi.Output[str]
    """
    The ID of the Subnet which the App Service Environment should be connected to. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource. Changing this forces a new resource to be created.
    """
    user_whitelisted_ip_ranges: pulumi.Output[list]
    def __init__(__self__, resource_name, opts=None, allowed_user_ip_cidrs=None, front_end_scale_factor=None, internal_load_balancing_mode=None, name=None, pricing_tier=None, resource_group_name=None, subnet_id=None, tags=None, user_whitelisted_ip_ranges=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an App Service Environment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="westeurope")
        example_virtual_network = azure.network.VirtualNetwork("exampleVirtualNetwork",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            address_spaces=["10.0.0.0/16"])
        ase = azure.network.Subnet("ase",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefix="10.0.1.0/24")
        gateway = azure.network.Subnet("gateway",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefix="10.0.2.0/24")
        example_environment = azure.appservice.Environment("exampleEnvironment",
            subnet_id=ase.id,
            pricing_tier="I2",
            front_end_scale_factor=10,
            internal_load_balancing_mode="Web, Publishing",
            allowed_user_ip_cidrs=[
                "11.22.33.44/32",
                "55.66.77.0/24",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] allowed_user_ip_cidrs: Allowed user added IP ranges on the ASE database. Use the addresses you want to set as the explicit egress address ranges.
        :param pulumi.Input[float] front_end_scale_factor: Scale factor for front end instances. Possible values are between `5` and `15`. Defaults to `15`.
        :param pulumi.Input[str] internal_load_balancing_mode: Specifies which endpoints to serve internally in the Virtual Network for the App Service Environment. Possible values are `None`, `Web`, `Publishing` and combined value `"Web, Publishing"`. Defaults to `None`.
        :param pulumi.Input[str] name: The name of the App Service Environment. Changing this forces a new resource to be created.
        :param pulumi.Input[str] pricing_tier: Pricing tier for the front end instances. Possible values are `I1`, `I2` and `I3`. Defaults to `I1`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the App Service Environment exists. Defaults to the Resource Group of the Subnet (specified by `subnet_id`).
        :param pulumi.Input[str] subnet_id: The ID of the Subnet which the App Service Environment should be connected to. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource. Changing this forces a new resource to be created.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['allowed_user_ip_cidrs'] = allowed_user_ip_cidrs
            __props__['front_end_scale_factor'] = front_end_scale_factor
            __props__['internal_load_balancing_mode'] = internal_load_balancing_mode
            __props__['name'] = name
            __props__['pricing_tier'] = pricing_tier
            __props__['resource_group_name'] = resource_group_name
            if subnet_id is None:
                raise TypeError("Missing required property 'subnet_id'")
            __props__['subnet_id'] = subnet_id
            __props__['tags'] = tags
            if user_whitelisted_ip_ranges is not None:
                warnings.warn("this property has been renamed to `allowed_user_ip_cidrs` better reflect the expected ip range format", DeprecationWarning)
                pulumi.log.warn("user_whitelisted_ip_ranges is deprecated: this property has been renamed to `allowed_user_ip_cidrs` better reflect the expected ip range format")
            __props__['user_whitelisted_ip_ranges'] = user_whitelisted_ip_ranges
            __props__['location'] = None
        super(Environment, __self__).__init__(
            'azure:appservice/environment:Environment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, allowed_user_ip_cidrs=None, front_end_scale_factor=None, internal_load_balancing_mode=None, location=None, name=None, pricing_tier=None, resource_group_name=None, subnet_id=None, tags=None, user_whitelisted_ip_ranges=None):
        """
        Get an existing Environment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] allowed_user_ip_cidrs: Allowed user added IP ranges on the ASE database. Use the addresses you want to set as the explicit egress address ranges.
        :param pulumi.Input[float] front_end_scale_factor: Scale factor for front end instances. Possible values are between `5` and `15`. Defaults to `15`.
        :param pulumi.Input[str] internal_load_balancing_mode: Specifies which endpoints to serve internally in the Virtual Network for the App Service Environment. Possible values are `None`, `Web`, `Publishing` and combined value `"Web, Publishing"`. Defaults to `None`.
        :param pulumi.Input[str] location: The location where the App Service Environment exists.
        :param pulumi.Input[str] name: The name of the App Service Environment. Changing this forces a new resource to be created.
        :param pulumi.Input[str] pricing_tier: Pricing tier for the front end instances. Possible values are `I1`, `I2` and `I3`. Defaults to `I1`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the App Service Environment exists. Defaults to the Resource Group of the Subnet (specified by `subnet_id`).
        :param pulumi.Input[str] subnet_id: The ID of the Subnet which the App Service Environment should be connected to. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["allowed_user_ip_cidrs"] = allowed_user_ip_cidrs
        __props__["front_end_scale_factor"] = front_end_scale_factor
        __props__["internal_load_balancing_mode"] = internal_load_balancing_mode
        __props__["location"] = location
        __props__["name"] = name
        __props__["pricing_tier"] = pricing_tier
        __props__["resource_group_name"] = resource_group_name
        __props__["subnet_id"] = subnet_id
        __props__["tags"] = tags
        __props__["user_whitelisted_ip_ranges"] = user_whitelisted_ip_ranges
        return Environment(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class LinkedService(pulumi.CustomResource):
    linked_service_name: pulumi.Output[str]
    """
    Name of the type of linkedServices resource to connect to the Log Analytics Workspace specified in `workspace_name`. Currently it defaults to and only supports `automation` as a value. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The automatically generated name of the Linked Service. This cannot be specified. The format is always `<workspace_name>/<linked_service_name>` e.g. `workspace1/Automation`
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which the Log Analytics Linked Service is created. Changing this forces a new resource to be created.
    """
    resource_id: pulumi.Output[str]
    """
    The ID of the Resource that will be linked to the workspace. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    workspace_name: pulumi.Output[str]
    """
    Name of the Log Analytics Workspace that will contain the linkedServices resource. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, linked_service_name=None, resource_group_name=None, resource_id=None, tags=None, workspace_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Links a Log Analytics (formally Operational Insights) Workspace to another resource. The (currently) only linkable service is an Azure Automation Account.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_account = azure.automation.Account("exampleAccount",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            sku=[{
                "name": "Basic",
            }],
            tags={
                "environment": "development",
            })
        example_analytics_workspace = azure.operationalinsights.AnalyticsWorkspace("exampleAnalyticsWorkspace",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            sku="PerGB2018",
            retention_in_days=30)
        example_linked_service = azure.loganalytics.LinkedService("exampleLinkedService",
            resource_group_name=example_resource_group.name,
            workspace_name=example_analytics_workspace.name,
            resource_id=example_account.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] linked_service_name: Name of the type of linkedServices resource to connect to the Log Analytics Workspace specified in `workspace_name`. Currently it defaults to and only supports `automation` as a value. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Log Analytics Linked Service is created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_id: The ID of the Resource that will be linked to the workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] workspace_name: Name of the Log Analytics Workspace that will contain the linkedServices resource. Changing this forces a new resource to be created.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['linked_service_name'] = linked_service_name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if resource_id is None:
                raise TypeError("Missing required property 'resource_id'")
            __props__['resource_id'] = resource_id
            __props__['tags'] = tags
            if workspace_name is None:
                raise TypeError("Missing required property 'workspace_name'")
            __props__['workspace_name'] = workspace_name
            __props__['name'] = None
        super(LinkedService, __self__).__init__(
            'azure:loganalytics/linkedService:LinkedService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, linked_service_name=None, name=None, resource_group_name=None, resource_id=None, tags=None, workspace_name=None):
        """
        Get an existing LinkedService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] linked_service_name: Name of the type of linkedServices resource to connect to the Log Analytics Workspace specified in `workspace_name`. Currently it defaults to and only supports `automation` as a value. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The automatically generated name of the Linked Service. This cannot be specified. The format is always `<workspace_name>/<linked_service_name>` e.g. `workspace1/Automation`
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the Log Analytics Linked Service is created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_id: The ID of the Resource that will be linked to the workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] workspace_name: Name of the Log Analytics Workspace that will contain the linkedServices resource. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["linked_service_name"] = linked_service_name
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["resource_id"] = resource_id
        __props__["tags"] = tags
        __props__["workspace_name"] = workspace_name
        return LinkedService(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class AssignmentDedicatedHost(pulumi.CustomResource):
    dedicated_host_id: pulumi.Output[str]
    """
    Specifies the Dedicated Host ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    maintenance_configuration_id: pulumi.Output[str]
    """
    Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, dedicated_host_id=None, location=None, maintenance_configuration_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a maintenance assignment to Dedicated Host.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_dedicated_host_group = azure.compute.DedicatedHostGroup("exampleDedicatedHostGroup",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            platform_fault_domain_count=2)
        example_dedicated_host = azure.compute.DedicatedHost("exampleDedicatedHost",
            location=example_resource_group.location,
            dedicated_host_group_id=example_dedicated_host_group.id,
            sku_name="DSv3-Type1",
            platform_fault_domain=1)
        example_configuration = azure.maintenance.Configuration("exampleConfiguration",
            resource_group_name=example_resource_group.name,
            location=example_resource_group.location,
            scope="All")
        example_assignment_dedicated_host = azure.maintenance.AssignmentDedicatedHost("exampleAssignmentDedicatedHost",
            location=example_resource_group.location,
            maintenance_configuration_id=example_configuration.id,
            dedicated_host_id=example_dedicated_host.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dedicated_host_id: Specifies the Dedicated Host ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if dedicated_host_id is None:
                raise TypeError("Missing required property 'dedicated_host_id'")
            __props__['dedicated_host_id'] = dedicated_host_id
            __props__['location'] = location
            if maintenance_configuration_id is None:
                raise TypeError("Missing required property 'maintenance_configuration_id'")
            __props__['maintenance_configuration_id'] = maintenance_configuration_id
        super(AssignmentDedicatedHost, __self__).__init__(
            'azure:maintenance/assignmentDedicatedHost:AssignmentDedicatedHost',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, dedicated_host_id=None, location=None, maintenance_configuration_id=None):
        """
        Get an existing AssignmentDedicatedHost resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dedicated_host_id: Specifies the Dedicated Host ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["dedicated_host_id"] = dedicated_host_id
        __props__["location"] = location
        __props__["maintenance_configuration_id"] = maintenance_configuration_id
        return AssignmentDedicatedHost(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
